import numpy
import math
import matplotlib.pyplot as plt

#----------Konstanter----------------------------------------------------------

SB    = 5.67*10**(-8) #Stefan-Boltzmanns konstant

#Konstanter Sola
T_s   = 5770          #Temperaturen til sola i Kelvin
r_s   = 696340000     #Radius Sola

#Konstanter jorda
a_js     = 1.49*10**11   #Avstand mellom jorda og sola
r_j      = 6371000       #Radius Jorda
albedo_j = 0.3           #Jordas anslåtte albedo
T_j      = 290.05        #Faktisk gjennomsnittstemperatur på jorda

#Konstanter Rigil Kentaurus
a_jrk = 4.125*10**16    #Avstand mellom jorda og Rigil Kentaurus
r_rk  = r_s             #Radius, ca lik størrelse som sola
T_rk  = 5790            #Temperatur [K]

#Konstanter månen
a_ms     = a_js             #Avstand mellom månen og sola (samme som jorda)
r_m      = 1737.4*10**3     #Radius månen
albedo_m = 0.14             #Albedo månen

#---------------------------------------------------------------------------------

def DrivhusModell(r_kilde, T_kilde, avstand, albedo, emissitivitet):
    M_kilde       = SB*T_kilde**4
    M_d             = M_kilde*(r_kilde/avstand)**2
    T = (M_d*(1-albedo)/(4*SB*(1-emissitivitet/2)))**(1/4)
    return T, M_d


def EmissivitetBeregner(r_kilde, T_kilde, avstand, albedo):
    e = 0.75 #startverdi for emissivitet
    while e <= 0.78:
        T,M = DrivhusModell(r_s,T_s,a_js,albedo_j,e)
        plt.plot(e, T-273.15,'.') #plotter temperaturen for emissiviteten
        e = e + 0.001 #For hvertsteg i løkken øker emissitiviteten med 0.001 helt til den når sluttverdien
    #Her plottes grafen
    plt.title('Overflatetemperatur ved emissitivitet')
    plt.xlabel('Emissivitet')
    plt.ylabel('Temperatur')
    plt.show()
    return 0

EmissivitetBeregner(r_s,T_s,a_js,albedo_j)

#Fjern hashtaggene på hver linje under for å få output etter 
#at du har funnet en verdi for emissitiviteten
#--------------------------------------------------------------------------------
a             = 0.3
emissivitet = 0.77
T,M = DrivhusModell(r_s, T_s, a_js, a, emissivitet)
print('Albedo: ', a)
print('emissivitet: ', emissivitet)
print('Innstrålingstetthet: ', M)
print('Overflatetemperatur: ', T-273.15, 'grader Celsius')